@@ -7,6 +7,9 @@
 #' 
 #' @param inLakeMorpho An object of \code{\link{lakeMorphoClass}}.  Output of the 
 #'        \code{\link{lakeSurroundTopo}} function would be appropriate as input
+#' @param zmax Maximum depth of the lake.  If none entered and elevation dataset
+#'             is inlcuded in inLakeMorpho, \code{\link{lakeMaxDepth}} is used 
+#'             to estimate a maximum depth.
 #' @param correctFactor This a factor used by \code{\link{lakeMaxDepth}} to 
 #'        correct the predicted maximum lake depth.  Defaults to 1.
 #' @export
@@ -26,17 +29,20 @@
 #' data(lakes)
 #' lakeVolume(inputLM)
 
-lakeVolume <- function(inLakeMorpho, correctFactor = 1) {
+lakeVolume <- function(inLakeMorpho, zmax = NULL, correctFactor = 1) {
     if (class(inLakeMorpho) != "lakeMorpho") {
       stop("Input data is not of class 'lakeMorpho'.  Run lakeSurround Topo or lakeMorphoClass first.")
     }
-    if(is.null(inLakeMorpho$elev)){
-      stop("Input elevation dataset required to estimate depth related metrics.  
-             Run lakeSurround Topo first with elevation included")
+    if(is.null(inLakeMorpho$elev) & is.null(zmax)){
+      stop("No maximum depth provided and no elevation data included to estimate 
+            maximum depth.  Provide a maximum depth or run lakeSurroundTopo 
+            first with elevation included")
     }
-    Dmax <- max(inLakeMorpho$lakeDistance@data@values, na.rm = T)
-    Zmax <- lakeMaxDepth(inLakeMorpho, correctFactor)
-    lakevol <- sum((inLakeMorpho$lakeDistance@data@values * Zmax/Dmax) * res(inLakeMorpho$lakeDistance)[1] * 
+    dmax <- max(inLakeMorpho$lakeDistance@data@values, na.rm = T)
+    if(is.null(zmax)) {
+      zmax <- lakeMaxDepth(inLakeMorpho, correctFactor)
+    }
+    lakevol <- sum((inLakeMorpho$lakeDistance@data@values * zmax/dmax) * res(inLakeMorpho$lakeDistance)[1] * 
         res(inLakeMorpho$lakeDistance)[2], na.rm = T)
     return(lakevol)
 } 
